# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_starrocks20221019 import models as main_models
from darabonba.model import DaraModel

class RestartNodesRequest(DaraModel):
    def __init__(
        self,
        instance_id: str = None,
        restart_node_groups: List[main_models.RestartNodesRequestRestartNodeGroups] = None,
    ):
        self.instance_id = instance_id
        self.restart_node_groups = restart_node_groups

    def validate(self):
        if self.restart_node_groups:
            for v1 in self.restart_node_groups:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        result['RestartNodeGroups'] = []
        if self.restart_node_groups is not None:
            for k1 in self.restart_node_groups:
                result['RestartNodeGroups'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        self.restart_node_groups = []
        if m.get('RestartNodeGroups') is not None:
            for k1 in m.get('RestartNodeGroups'):
                temp_model = main_models.RestartNodesRequestRestartNodeGroups()
                self.restart_node_groups.append(temp_model.from_map(k1))

        return self

class RestartNodesRequestRestartNodeGroups(DaraModel):
    def __init__(
        self,
        fast_mode: bool = None,
        node_group_id: str = None,
        node_ids: List[str] = None,
    ):
        self.fast_mode = fast_mode
        self.node_group_id = node_group_id
        self.node_ids = node_ids

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.fast_mode is not None:
            result['FastMode'] = self.fast_mode

        if self.node_group_id is not None:
            result['NodeGroupId'] = self.node_group_id

        if self.node_ids is not None:
            result['NodeIds'] = self.node_ids

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('FastMode') is not None:
            self.fast_mode = m.get('FastMode')

        if m.get('NodeGroupId') is not None:
            self.node_group_id = m.get('NodeGroupId')

        if m.get('NodeIds') is not None:
            self.node_ids = m.get('NodeIds')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from ._instance_config_dto import InstanceConfigDto
from ._resource_spec import ResourceSpec
from ._add_gateway_request import AddGatewayRequest
from ._add_gateway_response_body import AddGatewayResponseBody
from ._add_gateway_response import AddGatewayResponse
from ._change_resource_group_request import ChangeResourceGroupRequest
from ._change_resource_group_response_body import ChangeResourceGroupResponseBody
from ._change_resource_group_response import ChangeResourceGroupResponse
from ._create_instance_v1request import CreateInstanceV1Request
from ._create_instance_v1response_body import CreateInstanceV1ResponseBody
from ._create_instance_v1response import CreateInstanceV1Response
from ._create_service_linked_role_response_body import CreateServiceLinkedRoleResponseBody
from ._create_service_linked_role_response import CreateServiceLinkedRoleResponse
from ._delete_gateway_request import DeleteGatewayRequest
from ._delete_gateway_response_body import DeleteGatewayResponseBody
from ._delete_gateway_response import DeleteGatewayResponse
from ._describe_instances_request import DescribeInstancesRequest
from ._describe_instances_shrink_request import DescribeInstancesShrinkRequest
from ._describe_instances_response_body import DescribeInstancesResponseBody
from ._describe_instances_response import DescribeInstancesResponse
from ._describe_node_groups_request import DescribeNodeGroupsRequest
from ._describe_node_groups_response_body import DescribeNodeGroupsResponseBody
from ._describe_node_groups_response import DescribeNodeGroupsResponse
from ._disable_sslconnection_request import DisableSSLConnectionRequest
from ._disable_sslconnection_response_body import DisableSSLConnectionResponseBody
from ._disable_sslconnection_response import DisableSSLConnectionResponse
from ._enable_sslconnection_request import EnableSSLConnectionRequest
from ._enable_sslconnection_response_body import EnableSSLConnectionResponseBody
from ._enable_sslconnection_response import EnableSSLConnectionResponse
from ._get_instance_feature_gate_request import GetInstanceFeatureGateRequest
from ._get_instance_feature_gate_response_body import GetInstanceFeatureGateResponseBody
from ._get_instance_feature_gate_response import GetInstanceFeatureGateResponse
from ._isolate_leader_request import IsolateLeaderRequest
from ._isolate_leader_response_body import IsolateLeaderResponseBody
from ._isolate_leader_response import IsolateLeaderResponse
from ._list_gateway_request import ListGatewayRequest
from ._list_gateway_response_body import ListGatewayResponseBody
from ._list_gateway_response import ListGatewayResponse
from ._modify_charge_type_request import ModifyChargeTypeRequest
from ._modify_charge_type_response_body import ModifyChargeTypeResponseBody
from ._modify_charge_type_response import ModifyChargeTypeResponse
from ._modify_cu_request import ModifyCuRequest
from ._modify_cu_response_body import ModifyCuResponseBody
from ._modify_cu_response import ModifyCuResponse
from ._modify_cu_pre_check_request import ModifyCuPreCheckRequest
from ._modify_cu_pre_check_response_body import ModifyCuPreCheckResponseBody
from ._modify_cu_pre_check_response import ModifyCuPreCheckResponse
from ._modify_disk_number_request import ModifyDiskNumberRequest
from ._modify_disk_number_response_body import ModifyDiskNumberResponseBody
from ._modify_disk_number_response import ModifyDiskNumberResponse
from ._modify_disk_performance_level_request import ModifyDiskPerformanceLevelRequest
from ._modify_disk_performance_level_response_body import ModifyDiskPerformanceLevelResponseBody
from ._modify_disk_performance_level_response import ModifyDiskPerformanceLevelResponse
from ._modify_disk_size_request import ModifyDiskSizeRequest
from ._modify_disk_size_response_body import ModifyDiskSizeResponseBody
from ._modify_disk_size_response import ModifyDiskSizeResponse
from ._modify_disk_type_request import ModifyDiskTypeRequest
from ._modify_disk_type_response_body import ModifyDiskTypeResponseBody
from ._modify_disk_type_response import ModifyDiskTypeResponse
from ._modify_node_number_request import ModifyNodeNumberRequest
from ._modify_node_number_response_body import ModifyNodeNumberResponseBody
from ._modify_node_number_response import ModifyNodeNumberResponse
from ._modify_node_number_pre_check_request import ModifyNodeNumberPreCheckRequest
from ._modify_node_number_pre_check_response_body import ModifyNodeNumberPreCheckResponseBody
from ._modify_node_number_pre_check_response import ModifyNodeNumberPreCheckResponse
from ._query_upgradable_versions_request import QueryUpgradableVersionsRequest
from ._query_upgradable_versions_response_body import QueryUpgradableVersionsResponseBody
from ._query_upgradable_versions_response import QueryUpgradableVersionsResponse
from ._release_instance_request import ReleaseInstanceRequest
from ._release_instance_response_body import ReleaseInstanceResponseBody
from ._release_instance_response import ReleaseInstanceResponse
from ._restart_instance_request import RestartInstanceRequest
from ._restart_instance_response_body import RestartInstanceResponseBody
from ._restart_instance_response import RestartInstanceResponse
from ._restart_node_group_request import RestartNodeGroupRequest
from ._restart_node_group_response_body import RestartNodeGroupResponseBody
from ._restart_node_group_response import RestartNodeGroupResponse
from ._restart_nodes_request import RestartNodesRequest
from ._restart_nodes_response_body import RestartNodesResponseBody
from ._restart_nodes_response import RestartNodesResponse
from ._restore_instance_request import RestoreInstanceRequest
from ._restore_instance_response_body import RestoreInstanceResponseBody
from ._restore_instance_response import RestoreInstanceResponse
from ._resume_instance_request import ResumeInstanceRequest
from ._resume_instance_response_body import ResumeInstanceResponseBody
from ._resume_instance_response import ResumeInstanceResponse
from ._tag_resources_request import TagResourcesRequest
from ._tag_resources_response_body import TagResourcesResponseBody
from ._tag_resources_response import TagResourcesResponse
from ._toggle_public_slb_request import TogglePublicSlbRequest
from ._toggle_public_slb_response_body import TogglePublicSlbResponseBody
from ._toggle_public_slb_response import TogglePublicSlbResponse
from ._un_tag_resources_request import UnTagResourcesRequest
from ._un_tag_resources_shrink_request import UnTagResourcesShrinkRequest
from ._un_tag_resources_response_body import UnTagResourcesResponseBody
from ._un_tag_resources_response import UnTagResourcesResponse
from ._update_gateway_request import UpdateGatewayRequest
from ._update_gateway_response_body import UpdateGatewayResponseBody
from ._update_gateway_response import UpdateGatewayResponse
from ._update_instance_name_request import UpdateInstanceNameRequest
from ._update_instance_name_response_body import UpdateInstanceNameResponseBody
from ._update_instance_name_response import UpdateInstanceNameResponse
from ._upgrade_version_request import UpgradeVersionRequest
from ._upgrade_version_response_body import UpgradeVersionResponseBody
from ._upgrade_version_response import UpgradeVersionResponse
from ._create_instance_v1request import CreateInstanceV1RequestAgentNodeGroup
from ._create_instance_v1request import CreateInstanceV1RequestBackendNodeGroups
from ._create_instance_v1request import CreateInstanceV1RequestFrontendNodeGroups
from ._create_instance_v1request import CreateInstanceV1RequestObserverNodeGroups
from ._create_instance_v1request import CreateInstanceV1RequestTags
from ._create_instance_v1request import CreateInstanceV1RequestVSwitches
from ._create_instance_v1response_body import CreateInstanceV1ResponseBodyData
from ._describe_instances_request import DescribeInstancesRequestTag
from ._describe_instances_response_body import DescribeInstancesResponseBodyDataTags
from ._describe_instances_response_body import DescribeInstancesResponseBodyDataVSwitches
from ._describe_instances_response_body import DescribeInstancesResponseBodyData
from ._describe_node_groups_response_body import DescribeNodeGroupsResponseBodyDataNodeInfo
from ._describe_node_groups_response_body import DescribeNodeGroupsResponseBodyDataTags
from ._describe_node_groups_response_body import DescribeNodeGroupsResponseBodyData
from ._get_instance_feature_gate_response_body import GetInstanceFeatureGateResponseBodyData
from ._list_gateway_response_body import ListGatewayResponseBodyData
from ._modify_cu_pre_check_response_body import ModifyCuPreCheckResponseBodyData
from ._modify_node_number_pre_check_response_body import ModifyNodeNumberPreCheckResponseBodyData
from ._restart_nodes_request import RestartNodesRequestRestartNodeGroups
from ._restore_instance_request import RestoreInstanceRequestTags
from ._restore_instance_request import RestoreInstanceRequestVSwitches
from ._restore_instance_response_body import RestoreInstanceResponseBodyData
from ._tag_resources_request import TagResourcesRequestTag

__all__ = [
    InstanceConfigDto,
    ResourceSpec,
    AddGatewayRequest,
    AddGatewayResponseBody,
    AddGatewayResponse,
    ChangeResourceGroupRequest,
    ChangeResourceGroupResponseBody,
    ChangeResourceGroupResponse,
    CreateInstanceV1Request,
    CreateInstanceV1ResponseBody,
    CreateInstanceV1Response,
    CreateServiceLinkedRoleResponseBody,
    CreateServiceLinkedRoleResponse,
    DeleteGatewayRequest,
    DeleteGatewayResponseBody,
    DeleteGatewayResponse,
    DescribeInstancesRequest,
    DescribeInstancesShrinkRequest,
    DescribeInstancesResponseBody,
    DescribeInstancesResponse,
    DescribeNodeGroupsRequest,
    DescribeNodeGroupsResponseBody,
    DescribeNodeGroupsResponse,
    DisableSSLConnectionRequest,
    DisableSSLConnectionResponseBody,
    DisableSSLConnectionResponse,
    EnableSSLConnectionRequest,
    EnableSSLConnectionResponseBody,
    EnableSSLConnectionResponse,
    GetInstanceFeatureGateRequest,
    GetInstanceFeatureGateResponseBody,
    GetInstanceFeatureGateResponse,
    IsolateLeaderRequest,
    IsolateLeaderResponseBody,
    IsolateLeaderResponse,
    ListGatewayRequest,
    ListGatewayResponseBody,
    ListGatewayResponse,
    ModifyChargeTypeRequest,
    ModifyChargeTypeResponseBody,
    ModifyChargeTypeResponse,
    ModifyCuRequest,
    ModifyCuResponseBody,
    ModifyCuResponse,
    ModifyCuPreCheckRequest,
    ModifyCuPreCheckResponseBody,
    ModifyCuPreCheckResponse,
    ModifyDiskNumberRequest,
    ModifyDiskNumberResponseBody,
    ModifyDiskNumberResponse,
    ModifyDiskPerformanceLevelRequest,
    ModifyDiskPerformanceLevelResponseBody,
    ModifyDiskPerformanceLevelResponse,
    ModifyDiskSizeRequest,
    ModifyDiskSizeResponseBody,
    ModifyDiskSizeResponse,
    ModifyDiskTypeRequest,
    ModifyDiskTypeResponseBody,
    ModifyDiskTypeResponse,
    ModifyNodeNumberRequest,
    ModifyNodeNumberResponseBody,
    ModifyNodeNumberResponse,
    ModifyNodeNumberPreCheckRequest,
    ModifyNodeNumberPreCheckResponseBody,
    ModifyNodeNumberPreCheckResponse,
    QueryUpgradableVersionsRequest,
    QueryUpgradableVersionsResponseBody,
    QueryUpgradableVersionsResponse,
    ReleaseInstanceRequest,
    ReleaseInstanceResponseBody,
    ReleaseInstanceResponse,
    RestartInstanceRequest,
    RestartInstanceResponseBody,
    RestartInstanceResponse,
    RestartNodeGroupRequest,
    RestartNodeGroupResponseBody,
    RestartNodeGroupResponse,
    RestartNodesRequest,
    RestartNodesResponseBody,
    RestartNodesResponse,
    RestoreInstanceRequest,
    RestoreInstanceResponseBody,
    RestoreInstanceResponse,
    ResumeInstanceRequest,
    ResumeInstanceResponseBody,
    ResumeInstanceResponse,
    TagResourcesRequest,
    TagResourcesResponseBody,
    TagResourcesResponse,
    TogglePublicSlbRequest,
    TogglePublicSlbResponseBody,
    TogglePublicSlbResponse,
    UnTagResourcesRequest,
    UnTagResourcesShrinkRequest,
    UnTagResourcesResponseBody,
    UnTagResourcesResponse,
    UpdateGatewayRequest,
    UpdateGatewayResponseBody,
    UpdateGatewayResponse,
    UpdateInstanceNameRequest,
    UpdateInstanceNameResponseBody,
    UpdateInstanceNameResponse,
    UpgradeVersionRequest,
    UpgradeVersionResponseBody,
    UpgradeVersionResponse,
    CreateInstanceV1RequestAgentNodeGroup,
    CreateInstanceV1RequestBackendNodeGroups,
    CreateInstanceV1RequestFrontendNodeGroups,
    CreateInstanceV1RequestObserverNodeGroups,
    CreateInstanceV1RequestTags,
    CreateInstanceV1RequestVSwitches,
    CreateInstanceV1ResponseBodyData,
    DescribeInstancesRequestTag,
    DescribeInstancesResponseBodyDataTags,
    DescribeInstancesResponseBodyDataVSwitches,
    DescribeInstancesResponseBodyData,
    DescribeNodeGroupsResponseBodyDataNodeInfo,
    DescribeNodeGroupsResponseBodyDataTags,
    DescribeNodeGroupsResponseBodyData,
    GetInstanceFeatureGateResponseBodyData,
    ListGatewayResponseBodyData,
    ModifyCuPreCheckResponseBodyData,
    ModifyNodeNumberPreCheckResponseBodyData,
    RestartNodesRequestRestartNodeGroups,
    RestoreInstanceRequestTags,
    RestoreInstanceRequestVSwitches,
    RestoreInstanceResponseBodyData,
    TagResourcesRequestTag
]



# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class UpdateInstanceNameRequest(DaraModel):
    def __init__(
        self,
        cluster_name: str = None,
        instance_id: str = None,
    ):
        # The new name of the instance.
        # 
        # This parameter is required.
        self.cluster_name = cluster_name
        # The instance ID.
        # 
        # This parameter is required.
        self.instance_id = instance_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cluster_name is not None:
            result['ClusterName'] = self.cluster_name

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ClusterName') is not None:
            self.cluster_name = m.get('ClusterName')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_starrocks20221019 import models as main_models
from darabonba.model import DaraModel

class DescribeInstancesResponseBody(DaraModel):
    def __init__(
        self,
        data: List[main_models.DescribeInstancesResponseBodyData] = None,
        err_code: str = None,
        err_message: str = None,
        http_status_code: int = None,
        request_id: str = None,
        success: bool = None,
        total: int = None,
    ):
        self.data = data
        self.err_code = err_code
        self.err_message = err_message
        self.http_status_code = http_status_code
        self.request_id = request_id
        self.success = success
        self.total = total

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['Data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['Data'].append(k1.to_map() if k1 else None)

        if self.err_code is not None:
            result['ErrCode'] = self.err_code

        if self.err_message is not None:
            result['ErrMessage'] = self.err_message

        if self.http_status_code is not None:
            result['HttpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.data = []
        if m.get('Data') is not None:
            for k1 in m.get('Data'):
                temp_model = main_models.DescribeInstancesResponseBodyData()
                self.data.append(temp_model.from_map(k1))

        if m.get('ErrCode') is not None:
            self.err_code = m.get('ErrCode')

        if m.get('ErrMessage') is not None:
            self.err_message = m.get('ErrMessage')

        if m.get('HttpStatusCode') is not None:
            self.http_status_code = m.get('HttpStatusCode')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class DescribeInstancesResponseBodyData(DaraModel):
    def __init__(
        self,
        acl_id: str = None,
        architecture: str = None,
        begin_time: int = None,
        enable_auto_minor_version_upgrade: bool = None,
        enable_ssl: bool = None,
        enabled_audit_loader: bool = None,
        encrypted: bool = None,
        expire_time: int = None,
        instance_id: str = None,
        instance_name: str = None,
        instance_status: str = None,
        isolate_leader: bool = None,
        kms_key_id: str = None,
        maintainable_period: str = None,
        minor_version: str = None,
        monitor_type: str = None,
        oss_location: str = None,
        package_type: str = None,
        pay_type: str = None,
        region_id: str = None,
        resource_group_id: str = None,
        run_mode: str = None,
        running_time: int = None,
        security_group_managed: bool = None,
        sg_id: str = None,
        tags: List[main_models.DescribeInstancesResponseBodyDataTags] = None,
        v_switches: List[main_models.DescribeInstancesResponseBodyDataVSwitches] = None,
        version: str = None,
        vpc_id: str = None,
    ):
        self.acl_id = acl_id
        self.architecture = architecture
        self.begin_time = begin_time
        self.enable_auto_minor_version_upgrade = enable_auto_minor_version_upgrade
        self.enable_ssl = enable_ssl
        self.enabled_audit_loader = enabled_audit_loader
        self.encrypted = encrypted
        self.expire_time = expire_time
        self.instance_id = instance_id
        self.instance_name = instance_name
        self.instance_status = instance_status
        self.isolate_leader = isolate_leader
        self.kms_key_id = kms_key_id
        self.maintainable_period = maintainable_period
        self.minor_version = minor_version
        self.monitor_type = monitor_type
        self.oss_location = oss_location
        self.package_type = package_type
        self.pay_type = pay_type
        self.region_id = region_id
        self.resource_group_id = resource_group_id
        self.run_mode = run_mode
        self.running_time = running_time
        self.security_group_managed = security_group_managed
        self.sg_id = sg_id
        self.tags = tags
        self.v_switches = v_switches
        self.version = version
        # VPC ID。
        self.vpc_id = vpc_id

    def validate(self):
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()
        if self.v_switches:
            for v1 in self.v_switches:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.acl_id is not None:
            result['AclId'] = self.acl_id

        if self.architecture is not None:
            result['Architecture'] = self.architecture

        if self.begin_time is not None:
            result['BeginTime'] = self.begin_time

        if self.enable_auto_minor_version_upgrade is not None:
            result['EnableAutoMinorVersionUpgrade'] = self.enable_auto_minor_version_upgrade

        if self.enable_ssl is not None:
            result['EnableSSL'] = self.enable_ssl

        if self.enabled_audit_loader is not None:
            result['EnabledAuditLoader'] = self.enabled_audit_loader

        if self.encrypted is not None:
            result['Encrypted'] = self.encrypted

        if self.expire_time is not None:
            result['ExpireTime'] = self.expire_time

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.instance_name is not None:
            result['InstanceName'] = self.instance_name

        if self.instance_status is not None:
            result['InstanceStatus'] = self.instance_status

        if self.isolate_leader is not None:
            result['IsolateLeader'] = self.isolate_leader

        if self.kms_key_id is not None:
            result['KmsKeyId'] = self.kms_key_id

        if self.maintainable_period is not None:
            result['MaintainablePeriod'] = self.maintainable_period

        if self.minor_version is not None:
            result['MinorVersion'] = self.minor_version

        if self.monitor_type is not None:
            result['MonitorType'] = self.monitor_type

        if self.oss_location is not None:
            result['OssLocation'] = self.oss_location

        if self.package_type is not None:
            result['PackageType'] = self.package_type

        if self.pay_type is not None:
            result['PayType'] = self.pay_type

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.resource_group_id is not None:
            result['ResourceGroupId'] = self.resource_group_id

        if self.run_mode is not None:
            result['RunMode'] = self.run_mode

        if self.running_time is not None:
            result['RunningTime'] = self.running_time

        if self.security_group_managed is not None:
            result['SecurityGroupManaged'] = self.security_group_managed

        if self.sg_id is not None:
            result['SgId'] = self.sg_id

        result['Tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['Tags'].append(k1.to_map() if k1 else None)

        result['VSwitches'] = []
        if self.v_switches is not None:
            for k1 in self.v_switches:
                result['VSwitches'].append(k1.to_map() if k1 else None)

        if self.version is not None:
            result['Version'] = self.version

        if self.vpc_id is not None:
            result['VpcId'] = self.vpc_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AclId') is not None:
            self.acl_id = m.get('AclId')

        if m.get('Architecture') is not None:
            self.architecture = m.get('Architecture')

        if m.get('BeginTime') is not None:
            self.begin_time = m.get('BeginTime')

        if m.get('EnableAutoMinorVersionUpgrade') is not None:
            self.enable_auto_minor_version_upgrade = m.get('EnableAutoMinorVersionUpgrade')

        if m.get('EnableSSL') is not None:
            self.enable_ssl = m.get('EnableSSL')

        if m.get('EnabledAuditLoader') is not None:
            self.enabled_audit_loader = m.get('EnabledAuditLoader')

        if m.get('Encrypted') is not None:
            self.encrypted = m.get('Encrypted')

        if m.get('ExpireTime') is not None:
            self.expire_time = m.get('ExpireTime')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('InstanceName') is not None:
            self.instance_name = m.get('InstanceName')

        if m.get('InstanceStatus') is not None:
            self.instance_status = m.get('InstanceStatus')

        if m.get('IsolateLeader') is not None:
            self.isolate_leader = m.get('IsolateLeader')

        if m.get('KmsKeyId') is not None:
            self.kms_key_id = m.get('KmsKeyId')

        if m.get('MaintainablePeriod') is not None:
            self.maintainable_period = m.get('MaintainablePeriod')

        if m.get('MinorVersion') is not None:
            self.minor_version = m.get('MinorVersion')

        if m.get('MonitorType') is not None:
            self.monitor_type = m.get('MonitorType')

        if m.get('OssLocation') is not None:
            self.oss_location = m.get('OssLocation')

        if m.get('PackageType') is not None:
            self.package_type = m.get('PackageType')

        if m.get('PayType') is not None:
            self.pay_type = m.get('PayType')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('ResourceGroupId') is not None:
            self.resource_group_id = m.get('ResourceGroupId')

        if m.get('RunMode') is not None:
            self.run_mode = m.get('RunMode')

        if m.get('RunningTime') is not None:
            self.running_time = m.get('RunningTime')

        if m.get('SecurityGroupManaged') is not None:
            self.security_group_managed = m.get('SecurityGroupManaged')

        if m.get('SgId') is not None:
            self.sg_id = m.get('SgId')

        self.tags = []
        if m.get('Tags') is not None:
            for k1 in m.get('Tags'):
                temp_model = main_models.DescribeInstancesResponseBodyDataTags()
                self.tags.append(temp_model.from_map(k1))

        self.v_switches = []
        if m.get('VSwitches') is not None:
            for k1 in m.get('VSwitches'):
                temp_model = main_models.DescribeInstancesResponseBodyDataVSwitches()
                self.v_switches.append(temp_model.from_map(k1))

        if m.get('Version') is not None:
            self.version = m.get('Version')

        if m.get('VpcId') is not None:
            self.vpc_id = m.get('VpcId')

        return self

class DescribeInstancesResponseBodyDataVSwitches(DaraModel):
    def __init__(
        self,
        primary: bool = None,
        vsw_id: str = None,
        zone_id: str = None,
    ):
        self.primary = primary
        self.vsw_id = vsw_id
        self.zone_id = zone_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.primary is not None:
            result['Primary'] = self.primary

        if self.vsw_id is not None:
            result['VswId'] = self.vsw_id

        if self.zone_id is not None:
            result['ZoneId'] = self.zone_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Primary') is not None:
            self.primary = m.get('Primary')

        if m.get('VswId') is not None:
            self.vsw_id = m.get('VswId')

        if m.get('ZoneId') is not None:
            self.zone_id = m.get('ZoneId')

        return self

class DescribeInstancesResponseBodyDataTags(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        self.key = key
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ChangeResourceGroupRequest(DaraModel):
    def __init__(
        self,
        instance_id: str = None,
        new_resource_group_id: str = None,
        region_id: str = None,
        resource_type: str = None,
    ):
        # This parameter is required.
        self.instance_id = instance_id
        # This parameter is required.
        self.new_resource_group_id = new_resource_group_id
        self.region_id = region_id
        # This parameter is required.
        self.resource_type = resource_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.new_resource_group_id is not None:
            result['NewResourceGroupId'] = self.new_resource_group_id

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.resource_type is not None:
            result['ResourceType'] = self.resource_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('NewResourceGroupId') is not None:
            self.new_resource_group_id = m.get('NewResourceGroupId')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('ResourceType') is not None:
            self.resource_type = m.get('ResourceType')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_starrocks20221019 import models as main_models
from darabonba.model import DaraModel

class CreateInstanceV1Request(DaraModel):
    def __init__(
        self,
        admin_password: str = None,
        agent_node_group: main_models.CreateInstanceV1RequestAgentNodeGroup = None,
        auto_pay: bool = None,
        auto_renew: bool = None,
        backend_node_groups: List[main_models.CreateInstanceV1RequestBackendNodeGroups] = None,
        client_token: str = None,
        dlf_catalog_name: str = None,
        dlf_catalog_type: str = None,
        duration: int = None,
        encrypted: bool = None,
        frontend_node_groups: List[main_models.CreateInstanceV1RequestFrontendNodeGroups] = None,
        gateway_type: str = None,
        instance_name: str = None,
        kms_key_id: str = None,
        linked_ram_user_name: str = None,
        observer_node_groups: List[main_models.CreateInstanceV1RequestObserverNodeGroups] = None,
        oss_accessing_role_name: str = None,
        package_type: str = None,
        pay_type: str = None,
        pricing_cycle: str = None,
        principal_type: str = None,
        promotion_option_no: str = None,
        ram_user_id: str = None,
        region_id: str = None,
        resource_group_id: str = None,
        run_mode: str = None,
        tags: List[main_models.CreateInstanceV1RequestTags] = None,
        v_switches: List[main_models.CreateInstanceV1RequestVSwitches] = None,
        version: str = None,
        vpc_id: str = None,
        zone_id: str = None,
    ):
        # This parameter is required.
        self.admin_password = admin_password
        self.agent_node_group = agent_node_group
        self.auto_pay = auto_pay
        self.auto_renew = auto_renew
        self.backend_node_groups = backend_node_groups
        self.client_token = client_token
        self.dlf_catalog_name = dlf_catalog_name
        self.dlf_catalog_type = dlf_catalog_type
        self.duration = duration
        self.encrypted = encrypted
        self.frontend_node_groups = frontend_node_groups
        self.gateway_type = gateway_type
        # This parameter is required.
        self.instance_name = instance_name
        self.kms_key_id = kms_key_id
        self.linked_ram_user_name = linked_ram_user_name
        self.observer_node_groups = observer_node_groups
        self.oss_accessing_role_name = oss_accessing_role_name
        # This parameter is required.
        self.package_type = package_type
        # This parameter is required.
        self.pay_type = pay_type
        self.pricing_cycle = pricing_cycle
        self.principal_type = principal_type
        self.promotion_option_no = promotion_option_no
        self.ram_user_id = ram_user_id
        # This parameter is required.
        self.region_id = region_id
        self.resource_group_id = resource_group_id
        # This parameter is required.
        self.run_mode = run_mode
        self.tags = tags
        self.v_switches = v_switches
        # This parameter is required.
        self.version = version
        # VPC ID。
        # 
        # This parameter is required.
        self.vpc_id = vpc_id
        # This parameter is required.
        self.zone_id = zone_id

    def validate(self):
        if self.agent_node_group:
            self.agent_node_group.validate()
        if self.backend_node_groups:
            for v1 in self.backend_node_groups:
                 if v1:
                    v1.validate()
        if self.frontend_node_groups:
            for v1 in self.frontend_node_groups:
                 if v1:
                    v1.validate()
        if self.observer_node_groups:
            for v1 in self.observer_node_groups:
                 if v1:
                    v1.validate()
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()
        if self.v_switches:
            for v1 in self.v_switches:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.admin_password is not None:
            result['AdminPassword'] = self.admin_password

        if self.agent_node_group is not None:
            result['AgentNodeGroup'] = self.agent_node_group.to_map()

        if self.auto_pay is not None:
            result['AutoPay'] = self.auto_pay

        if self.auto_renew is not None:
            result['AutoRenew'] = self.auto_renew

        result['BackendNodeGroups'] = []
        if self.backend_node_groups is not None:
            for k1 in self.backend_node_groups:
                result['BackendNodeGroups'].append(k1.to_map() if k1 else None)

        if self.client_token is not None:
            result['ClientToken'] = self.client_token

        if self.dlf_catalog_name is not None:
            result['DlfCatalogName'] = self.dlf_catalog_name

        if self.dlf_catalog_type is not None:
            result['DlfCatalogType'] = self.dlf_catalog_type

        if self.duration is not None:
            result['Duration'] = self.duration

        if self.encrypted is not None:
            result['Encrypted'] = self.encrypted

        result['FrontendNodeGroups'] = []
        if self.frontend_node_groups is not None:
            for k1 in self.frontend_node_groups:
                result['FrontendNodeGroups'].append(k1.to_map() if k1 else None)

        if self.gateway_type is not None:
            result['GatewayType'] = self.gateway_type

        if self.instance_name is not None:
            result['InstanceName'] = self.instance_name

        if self.kms_key_id is not None:
            result['KmsKeyId'] = self.kms_key_id

        if self.linked_ram_user_name is not None:
            result['LinkedRamUserName'] = self.linked_ram_user_name

        result['ObserverNodeGroups'] = []
        if self.observer_node_groups is not None:
            for k1 in self.observer_node_groups:
                result['ObserverNodeGroups'].append(k1.to_map() if k1 else None)

        if self.oss_accessing_role_name is not None:
            result['OssAccessingRoleName'] = self.oss_accessing_role_name

        if self.package_type is not None:
            result['PackageType'] = self.package_type

        if self.pay_type is not None:
            result['PayType'] = self.pay_type

        if self.pricing_cycle is not None:
            result['PricingCycle'] = self.pricing_cycle

        if self.principal_type is not None:
            result['PrincipalType'] = self.principal_type

        if self.promotion_option_no is not None:
            result['PromotionOptionNo'] = self.promotion_option_no

        if self.ram_user_id is not None:
            result['RamUserId'] = self.ram_user_id

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.resource_group_id is not None:
            result['ResourceGroupId'] = self.resource_group_id

        if self.run_mode is not None:
            result['RunMode'] = self.run_mode

        result['Tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['Tags'].append(k1.to_map() if k1 else None)

        result['VSwitches'] = []
        if self.v_switches is not None:
            for k1 in self.v_switches:
                result['VSwitches'].append(k1.to_map() if k1 else None)

        if self.version is not None:
            result['Version'] = self.version

        if self.vpc_id is not None:
            result['VpcId'] = self.vpc_id

        if self.zone_id is not None:
            result['ZoneId'] = self.zone_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AdminPassword') is not None:
            self.admin_password = m.get('AdminPassword')

        if m.get('AgentNodeGroup') is not None:
            temp_model = main_models.CreateInstanceV1RequestAgentNodeGroup()
            self.agent_node_group = temp_model.from_map(m.get('AgentNodeGroup'))

        if m.get('AutoPay') is not None:
            self.auto_pay = m.get('AutoPay')

        if m.get('AutoRenew') is not None:
            self.auto_renew = m.get('AutoRenew')

        self.backend_node_groups = []
        if m.get('BackendNodeGroups') is not None:
            for k1 in m.get('BackendNodeGroups'):
                temp_model = main_models.CreateInstanceV1RequestBackendNodeGroups()
                self.backend_node_groups.append(temp_model.from_map(k1))

        if m.get('ClientToken') is not None:
            self.client_token = m.get('ClientToken')

        if m.get('DlfCatalogName') is not None:
            self.dlf_catalog_name = m.get('DlfCatalogName')

        if m.get('DlfCatalogType') is not None:
            self.dlf_catalog_type = m.get('DlfCatalogType')

        if m.get('Duration') is not None:
            self.duration = m.get('Duration')

        if m.get('Encrypted') is not None:
            self.encrypted = m.get('Encrypted')

        self.frontend_node_groups = []
        if m.get('FrontendNodeGroups') is not None:
            for k1 in m.get('FrontendNodeGroups'):
                temp_model = main_models.CreateInstanceV1RequestFrontendNodeGroups()
                self.frontend_node_groups.append(temp_model.from_map(k1))

        if m.get('GatewayType') is not None:
            self.gateway_type = m.get('GatewayType')

        if m.get('InstanceName') is not None:
            self.instance_name = m.get('InstanceName')

        if m.get('KmsKeyId') is not None:
            self.kms_key_id = m.get('KmsKeyId')

        if m.get('LinkedRamUserName') is not None:
            self.linked_ram_user_name = m.get('LinkedRamUserName')

        self.observer_node_groups = []
        if m.get('ObserverNodeGroups') is not None:
            for k1 in m.get('ObserverNodeGroups'):
                temp_model = main_models.CreateInstanceV1RequestObserverNodeGroups()
                self.observer_node_groups.append(temp_model.from_map(k1))

        if m.get('OssAccessingRoleName') is not None:
            self.oss_accessing_role_name = m.get('OssAccessingRoleName')

        if m.get('PackageType') is not None:
            self.package_type = m.get('PackageType')

        if m.get('PayType') is not None:
            self.pay_type = m.get('PayType')

        if m.get('PricingCycle') is not None:
            self.pricing_cycle = m.get('PricingCycle')

        if m.get('PrincipalType') is not None:
            self.principal_type = m.get('PrincipalType')

        if m.get('PromotionOptionNo') is not None:
            self.promotion_option_no = m.get('PromotionOptionNo')

        if m.get('RamUserId') is not None:
            self.ram_user_id = m.get('RamUserId')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('ResourceGroupId') is not None:
            self.resource_group_id = m.get('ResourceGroupId')

        if m.get('RunMode') is not None:
            self.run_mode = m.get('RunMode')

        self.tags = []
        if m.get('Tags') is not None:
            for k1 in m.get('Tags'):
                temp_model = main_models.CreateInstanceV1RequestTags()
                self.tags.append(temp_model.from_map(k1))

        self.v_switches = []
        if m.get('VSwitches') is not None:
            for k1 in m.get('VSwitches'):
                temp_model = main_models.CreateInstanceV1RequestVSwitches()
                self.v_switches.append(temp_model.from_map(k1))

        if m.get('Version') is not None:
            self.version = m.get('Version')

        if m.get('VpcId') is not None:
            self.vpc_id = m.get('VpcId')

        if m.get('ZoneId') is not None:
            self.zone_id = m.get('ZoneId')

        return self

class CreateInstanceV1RequestVSwitches(DaraModel):
    def __init__(
        self,
        vsw_id: str = None,
        zone_id: str = None,
    ):
        # This parameter is required.
        self.vsw_id = vsw_id
        self.zone_id = zone_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.vsw_id is not None:
            result['VswId'] = self.vsw_id

        if self.zone_id is not None:
            result['ZoneId'] = self.zone_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('VswId') is not None:
            self.vsw_id = m.get('VswId')

        if m.get('ZoneId') is not None:
            self.zone_id = m.get('ZoneId')

        return self

class CreateInstanceV1RequestTags(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        self.key = key
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self

class CreateInstanceV1RequestObserverNodeGroups(DaraModel):
    def __init__(
        self,
        cu: int = None,
        disk_number: int = None,
        local_storage_instance_type: str = None,
        resident_node_number: int = None,
        spec_type: str = None,
        storage_performance_level: str = None,
        storage_size: int = None,
        zone_id: str = None,
    ):
        self.cu = cu
        self.disk_number = disk_number
        self.local_storage_instance_type = local_storage_instance_type
        self.resident_node_number = resident_node_number
        self.spec_type = spec_type
        self.storage_performance_level = storage_performance_level
        self.storage_size = storage_size
        self.zone_id = zone_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cu is not None:
            result['cu'] = self.cu

        if self.disk_number is not None:
            result['diskNumber'] = self.disk_number

        if self.local_storage_instance_type is not None:
            result['localStorageInstanceType'] = self.local_storage_instance_type

        if self.resident_node_number is not None:
            result['residentNodeNumber'] = self.resident_node_number

        if self.spec_type is not None:
            result['specType'] = self.spec_type

        if self.storage_performance_level is not None:
            result['storagePerformanceLevel'] = self.storage_performance_level

        if self.storage_size is not None:
            result['storageSize'] = self.storage_size

        if self.zone_id is not None:
            result['zoneId'] = self.zone_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('cu') is not None:
            self.cu = m.get('cu')

        if m.get('diskNumber') is not None:
            self.disk_number = m.get('diskNumber')

        if m.get('localStorageInstanceType') is not None:
            self.local_storage_instance_type = m.get('localStorageInstanceType')

        if m.get('residentNodeNumber') is not None:
            self.resident_node_number = m.get('residentNodeNumber')

        if m.get('specType') is not None:
            self.spec_type = m.get('specType')

        if m.get('storagePerformanceLevel') is not None:
            self.storage_performance_level = m.get('storagePerformanceLevel')

        if m.get('storageSize') is not None:
            self.storage_size = m.get('storageSize')

        if m.get('zoneId') is not None:
            self.zone_id = m.get('zoneId')

        return self

class CreateInstanceV1RequestFrontendNodeGroups(DaraModel):
    def __init__(
        self,
        cu: int = None,
        disk_number: int = None,
        local_storage_instance_type: str = None,
        resident_node_number: int = None,
        spec_type: str = None,
        storage_performance_level: str = None,
        storage_size: int = None,
        zone_id: str = None,
    ):
        self.cu = cu
        self.disk_number = disk_number
        self.local_storage_instance_type = local_storage_instance_type
        self.resident_node_number = resident_node_number
        self.spec_type = spec_type
        self.storage_performance_level = storage_performance_level
        self.storage_size = storage_size
        self.zone_id = zone_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cu is not None:
            result['cu'] = self.cu

        if self.disk_number is not None:
            result['diskNumber'] = self.disk_number

        if self.local_storage_instance_type is not None:
            result['localStorageInstanceType'] = self.local_storage_instance_type

        if self.resident_node_number is not None:
            result['residentNodeNumber'] = self.resident_node_number

        if self.spec_type is not None:
            result['specType'] = self.spec_type

        if self.storage_performance_level is not None:
            result['storagePerformanceLevel'] = self.storage_performance_level

        if self.storage_size is not None:
            result['storageSize'] = self.storage_size

        if self.zone_id is not None:
            result['zoneId'] = self.zone_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('cu') is not None:
            self.cu = m.get('cu')

        if m.get('diskNumber') is not None:
            self.disk_number = m.get('diskNumber')

        if m.get('localStorageInstanceType') is not None:
            self.local_storage_instance_type = m.get('localStorageInstanceType')

        if m.get('residentNodeNumber') is not None:
            self.resident_node_number = m.get('residentNodeNumber')

        if m.get('specType') is not None:
            self.spec_type = m.get('specType')

        if m.get('storagePerformanceLevel') is not None:
            self.storage_performance_level = m.get('storagePerformanceLevel')

        if m.get('storageSize') is not None:
            self.storage_size = m.get('storageSize')

        if m.get('zoneId') is not None:
            self.zone_id = m.get('zoneId')

        return self

class CreateInstanceV1RequestBackendNodeGroups(DaraModel):
    def __init__(
        self,
        cu: int = None,
        disk_number: int = None,
        local_storage_instance_type: str = None,
        resident_node_number: int = None,
        spec_type: str = None,
        storage_performance_level: str = None,
        storage_size: int = None,
        zone_id: str = None,
    ):
        self.cu = cu
        self.disk_number = disk_number
        self.local_storage_instance_type = local_storage_instance_type
        self.resident_node_number = resident_node_number
        self.spec_type = spec_type
        self.storage_performance_level = storage_performance_level
        self.storage_size = storage_size
        self.zone_id = zone_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cu is not None:
            result['cu'] = self.cu

        if self.disk_number is not None:
            result['diskNumber'] = self.disk_number

        if self.local_storage_instance_type is not None:
            result['localStorageInstanceType'] = self.local_storage_instance_type

        if self.resident_node_number is not None:
            result['residentNodeNumber'] = self.resident_node_number

        if self.spec_type is not None:
            result['specType'] = self.spec_type

        if self.storage_performance_level is not None:
            result['storagePerformanceLevel'] = self.storage_performance_level

        if self.storage_size is not None:
            result['storageSize'] = self.storage_size

        if self.zone_id is not None:
            result['zoneId'] = self.zone_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('cu') is not None:
            self.cu = m.get('cu')

        if m.get('diskNumber') is not None:
            self.disk_number = m.get('diskNumber')

        if m.get('localStorageInstanceType') is not None:
            self.local_storage_instance_type = m.get('localStorageInstanceType')

        if m.get('residentNodeNumber') is not None:
            self.resident_node_number = m.get('residentNodeNumber')

        if m.get('specType') is not None:
            self.spec_type = m.get('specType')

        if m.get('storagePerformanceLevel') is not None:
            self.storage_performance_level = m.get('storagePerformanceLevel')

        if m.get('storageSize') is not None:
            self.storage_size = m.get('storageSize')

        if m.get('zoneId') is not None:
            self.zone_id = m.get('zoneId')

        return self



class CreateInstanceV1RequestAgentNodeGroup(DaraModel):
    def __init__(
        self,
        cu: int = None,
    ):
        self.cu = cu

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cu is not None:
            result['cu'] = self.cu

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('cu') is not None:
            self.cu = m.get('cu')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_starrocks20221019 import models as main_models
from darabonba.model import DaraModel

class GetInstanceFeatureGateResponseBody(DaraModel):
    def __init__(
        self,
        access_denied_detail: str = None,
        data: main_models.GetInstanceFeatureGateResponseBodyData = None,
        err_code: str = None,
        err_message: str = None,
        http_status_code: int = None,
        request_id: str = None,
        success: bool = None,
        total: int = None,
    ):
        # AccessDeniedDetail
        self.access_denied_detail = access_denied_detail
        self.data = data
        self.err_code = err_code
        self.err_message = err_message
        self.http_status_code = http_status_code
        self.request_id = request_id
        self.success = success
        self.total = total

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.access_denied_detail is not None:
            result['AccessDeniedDetail'] = self.access_denied_detail

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.err_code is not None:
            result['ErrCode'] = self.err_code

        if self.err_message is not None:
            result['ErrMessage'] = self.err_message

        if self.http_status_code is not None:
            result['HttpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccessDeniedDetail') is not None:
            self.access_denied_detail = m.get('AccessDeniedDetail')

        if m.get('Data') is not None:
            temp_model = main_models.GetInstanceFeatureGateResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('ErrCode') is not None:
            self.err_code = m.get('ErrCode')

        if m.get('ErrMessage') is not None:
            self.err_message = m.get('ErrMessage')

        if m.get('HttpStatusCode') is not None:
            self.http_status_code = m.get('HttpStatusCode')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class GetInstanceFeatureGateResponseBodyData(DaraModel):
    def __init__(
        self,
        console_control_restart: bool = None,
        enable_manage_mv: bool = None,
        full_managed_security_group: bool = None,
        mount_dlf_meta_token: bool = None,
        support_add_config_types: List[str] = None,
        support_backup: bool = None,
        support_create_agent: bool = None,
        support_create_non_standard_node_group: bool = None,
        support_eed: bool = None,
        support_enable_ai: bool = None,
        support_enable_ssl: bool = None,
        support_fast_mode_modify_config: bool = None,
        support_fast_mode_modify_resource: bool = None,
        support_fast_restart: bool = None,
        support_fe_gateway: bool = None,
        support_host_alias: bool = None,
        support_modify_timezone: bool = None,
        support_multi_az: bool = None,
        use_compute_node: bool = None,
        support_compaction_service: bool = None,
    ):
        self.console_control_restart = console_control_restart
        self.enable_manage_mv = enable_manage_mv
        self.full_managed_security_group = full_managed_security_group
        self.mount_dlf_meta_token = mount_dlf_meta_token
        self.support_add_config_types = support_add_config_types
        self.support_backup = support_backup
        self.support_create_agent = support_create_agent
        self.support_create_non_standard_node_group = support_create_non_standard_node_group
        self.support_eed = support_eed
        self.support_enable_ai = support_enable_ai
        self.support_enable_ssl = support_enable_ssl
        self.support_fast_mode_modify_config = support_fast_mode_modify_config
        self.support_fast_mode_modify_resource = support_fast_mode_modify_resource
        self.support_fast_restart = support_fast_restart
        self.support_fe_gateway = support_fe_gateway
        self.support_host_alias = support_host_alias
        self.support_modify_timezone = support_modify_timezone
        self.support_multi_az = support_multi_az
        self.use_compute_node = use_compute_node
        self.support_compaction_service = support_compaction_service

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.console_control_restart is not None:
            result['ConsoleControlRestart'] = self.console_control_restart

        if self.enable_manage_mv is not None:
            result['EnableManageMv'] = self.enable_manage_mv

        if self.full_managed_security_group is not None:
            result['FullManagedSecurityGroup'] = self.full_managed_security_group

        if self.mount_dlf_meta_token is not None:
            result['MountDlfMetaToken'] = self.mount_dlf_meta_token

        if self.support_add_config_types is not None:
            result['SupportAddConfigTypes'] = self.support_add_config_types

        if self.support_backup is not None:
            result['SupportBackup'] = self.support_backup

        if self.support_create_agent is not None:
            result['SupportCreateAgent'] = self.support_create_agent

        if self.support_create_non_standard_node_group is not None:
            result['SupportCreateNonStandardNodeGroup'] = self.support_create_non_standard_node_group

        if self.support_eed is not None:
            result['SupportEed'] = self.support_eed

        if self.support_enable_ai is not None:
            result['SupportEnableAi'] = self.support_enable_ai

        if self.support_enable_ssl is not None:
            result['SupportEnableSSL'] = self.support_enable_ssl

        if self.support_fast_mode_modify_config is not None:
            result['SupportFastModeModifyConfig'] = self.support_fast_mode_modify_config

        if self.support_fast_mode_modify_resource is not None:
            result['SupportFastModeModifyResource'] = self.support_fast_mode_modify_resource

        if self.support_fast_restart is not None:
            result['SupportFastRestart'] = self.support_fast_restart

        if self.support_fe_gateway is not None:
            result['SupportFeGateway'] = self.support_fe_gateway

        if self.support_host_alias is not None:
            result['SupportHostAlias'] = self.support_host_alias

        if self.support_modify_timezone is not None:
            result['SupportModifyTimezone'] = self.support_modify_timezone

        if self.support_multi_az is not None:
            result['SupportMultiAZ'] = self.support_multi_az

        if self.use_compute_node is not None:
            result['UseComputeNode'] = self.use_compute_node

        if self.support_compaction_service is not None:
            result['supportCompactionService'] = self.support_compaction_service

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ConsoleControlRestart') is not None:
            self.console_control_restart = m.get('ConsoleControlRestart')

        if m.get('EnableManageMv') is not None:
            self.enable_manage_mv = m.get('EnableManageMv')

        if m.get('FullManagedSecurityGroup') is not None:
            self.full_managed_security_group = m.get('FullManagedSecurityGroup')

        if m.get('MountDlfMetaToken') is not None:
            self.mount_dlf_meta_token = m.get('MountDlfMetaToken')

        if m.get('SupportAddConfigTypes') is not None:
            self.support_add_config_types = m.get('SupportAddConfigTypes')

        if m.get('SupportBackup') is not None:
            self.support_backup = m.get('SupportBackup')

        if m.get('SupportCreateAgent') is not None:
            self.support_create_agent = m.get('SupportCreateAgent')

        if m.get('SupportCreateNonStandardNodeGroup') is not None:
            self.support_create_non_standard_node_group = m.get('SupportCreateNonStandardNodeGroup')

        if m.get('SupportEed') is not None:
            self.support_eed = m.get('SupportEed')

        if m.get('SupportEnableAi') is not None:
            self.support_enable_ai = m.get('SupportEnableAi')

        if m.get('SupportEnableSSL') is not None:
            self.support_enable_ssl = m.get('SupportEnableSSL')

        if m.get('SupportFastModeModifyConfig') is not None:
            self.support_fast_mode_modify_config = m.get('SupportFastModeModifyConfig')

        if m.get('SupportFastModeModifyResource') is not None:
            self.support_fast_mode_modify_resource = m.get('SupportFastModeModifyResource')

        if m.get('SupportFastRestart') is not None:
            self.support_fast_restart = m.get('SupportFastRestart')

        if m.get('SupportFeGateway') is not None:
            self.support_fe_gateway = m.get('SupportFeGateway')

        if m.get('SupportHostAlias') is not None:
            self.support_host_alias = m.get('SupportHostAlias')

        if m.get('SupportModifyTimezone') is not None:
            self.support_modify_timezone = m.get('SupportModifyTimezone')

        if m.get('SupportMultiAZ') is not None:
            self.support_multi_az = m.get('SupportMultiAZ')

        if m.get('UseComputeNode') is not None:
            self.use_compute_node = m.get('UseComputeNode')

        if m.get('supportCompactionService') is not None:
            self.support_compaction_service = m.get('supportCompactionService')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_starrocks20221019 import models as main_models
from darabonba.model import DaraModel

class DescribeNodeGroupsResponseBody(DaraModel):
    def __init__(
        self,
        access_denied_detail: str = None,
        data: List[main_models.DescribeNodeGroupsResponseBodyData] = None,
        err_code: str = None,
        err_message: str = None,
        http_status_code: int = None,
        request_id: str = None,
        success: bool = None,
        total: int = None,
    ):
        self.access_denied_detail = access_denied_detail
        self.data = data
        self.err_code = err_code
        self.err_message = err_message
        self.http_status_code = http_status_code
        self.request_id = request_id
        self.success = success
        self.total = total

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.access_denied_detail is not None:
            result['AccessDeniedDetail'] = self.access_denied_detail

        result['Data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['Data'].append(k1.to_map() if k1 else None)

        if self.err_code is not None:
            result['ErrCode'] = self.err_code

        if self.err_message is not None:
            result['ErrMessage'] = self.err_message

        if self.http_status_code is not None:
            result['HttpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccessDeniedDetail') is not None:
            self.access_denied_detail = m.get('AccessDeniedDetail')

        self.data = []
        if m.get('Data') is not None:
            for k1 in m.get('Data'):
                temp_model = main_models.DescribeNodeGroupsResponseBodyData()
                self.data.append(temp_model.from_map(k1))

        if m.get('ErrCode') is not None:
            self.err_code = m.get('ErrCode')

        if m.get('ErrMessage') is not None:
            self.err_message = m.get('ErrMessage')

        if m.get('HttpStatusCode') is not None:
            self.http_status_code = m.get('HttpStatusCode')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class DescribeNodeGroupsResponseBodyData(DaraModel):
    def __init__(
        self,
        account_status: str = None,
        architecture: str = None,
        begin_time: int = None,
        billing_instance_id: str = None,
        commodity_code: str = None,
        component_type: str = None,
        cu: int = None,
        default_group: bool = None,
        description: str = None,
        disk_number: int = None,
        elastic_node_number: int = None,
        enable_public_network: bool = None,
        endpoint: str = None,
        expire_time: int = None,
        http_port: int = None,
        instance_id: str = None,
        local_storage_instance_type: str = None,
        memory_cpu_ratio: int = None,
        node_group_id: str = None,
        node_group_name: str = None,
        node_info: List[main_models.DescribeNodeGroupsResponseBodyDataNodeInfo] = None,
        pay_type: str = None,
        public_address: str = None,
        region_id: str = None,
        resident_node_number: int = None,
        running_time: int = None,
        spec_type: str = None,
        status: str = None,
        storage_performance_level: str = None,
        storage_size: int = None,
        tags: List[main_models.DescribeNodeGroupsResponseBodyDataTags] = None,
        target_elastic_node_number: int = None,
        zone_id: str = None,
    ):
        self.account_status = account_status
        self.architecture = architecture
        self.begin_time = begin_time
        self.billing_instance_id = billing_instance_id
        self.commodity_code = commodity_code
        self.component_type = component_type
        self.cu = cu
        self.default_group = default_group
        self.description = description
        self.disk_number = disk_number
        self.elastic_node_number = elastic_node_number
        self.enable_public_network = enable_public_network
        self.endpoint = endpoint
        self.expire_time = expire_time
        self.http_port = http_port
        self.instance_id = instance_id
        self.local_storage_instance_type = local_storage_instance_type
        self.memory_cpu_ratio = memory_cpu_ratio
        self.node_group_id = node_group_id
        self.node_group_name = node_group_name
        self.node_info = node_info
        self.pay_type = pay_type
        self.public_address = public_address
        self.region_id = region_id
        self.resident_node_number = resident_node_number
        self.running_time = running_time
        self.spec_type = spec_type
        self.status = status
        self.storage_performance_level = storage_performance_level
        self.storage_size = storage_size
        self.tags = tags
        self.target_elastic_node_number = target_elastic_node_number
        self.zone_id = zone_id

    def validate(self):
        if self.node_info:
            for v1 in self.node_info:
                 if v1:
                    v1.validate()
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.account_status is not None:
            result['AccountStatus'] = self.account_status

        if self.architecture is not None:
            result['Architecture'] = self.architecture

        if self.begin_time is not None:
            result['BeginTime'] = self.begin_time

        if self.billing_instance_id is not None:
            result['BillingInstanceId'] = self.billing_instance_id

        if self.commodity_code is not None:
            result['CommodityCode'] = self.commodity_code

        if self.component_type is not None:
            result['ComponentType'] = self.component_type

        if self.cu is not None:
            result['Cu'] = self.cu

        if self.default_group is not None:
            result['DefaultGroup'] = self.default_group

        if self.description is not None:
            result['Description'] = self.description

        if self.disk_number is not None:
            result['DiskNumber'] = self.disk_number

        if self.elastic_node_number is not None:
            result['ElasticNodeNumber'] = self.elastic_node_number

        if self.enable_public_network is not None:
            result['EnablePublicNetwork'] = self.enable_public_network

        if self.endpoint is not None:
            result['Endpoint'] = self.endpoint

        if self.expire_time is not None:
            result['ExpireTime'] = self.expire_time

        if self.http_port is not None:
            result['HttpPort'] = self.http_port

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.local_storage_instance_type is not None:
            result['LocalStorageInstanceType'] = self.local_storage_instance_type

        if self.memory_cpu_ratio is not None:
            result['MemoryCpuRatio'] = self.memory_cpu_ratio

        if self.node_group_id is not None:
            result['NodeGroupId'] = self.node_group_id

        if self.node_group_name is not None:
            result['NodeGroupName'] = self.node_group_name

        result['NodeInfo'] = []
        if self.node_info is not None:
            for k1 in self.node_info:
                result['NodeInfo'].append(k1.to_map() if k1 else None)

        if self.pay_type is not None:
            result['PayType'] = self.pay_type

        if self.public_address is not None:
            result['PublicAddress'] = self.public_address

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.resident_node_number is not None:
            result['ResidentNodeNumber'] = self.resident_node_number

        if self.running_time is not None:
            result['RunningTime'] = self.running_time

        if self.spec_type is not None:
            result['SpecType'] = self.spec_type

        if self.status is not None:
            result['Status'] = self.status

        if self.storage_performance_level is not None:
            result['StoragePerformanceLevel'] = self.storage_performance_level

        if self.storage_size is not None:
            result['StorageSize'] = self.storage_size

        result['Tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['Tags'].append(k1.to_map() if k1 else None)

        if self.target_elastic_node_number is not None:
            result['TargetElasticNodeNumber'] = self.target_elastic_node_number

        if self.zone_id is not None:
            result['ZoneId'] = self.zone_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccountStatus') is not None:
            self.account_status = m.get('AccountStatus')

        if m.get('Architecture') is not None:
            self.architecture = m.get('Architecture')

        if m.get('BeginTime') is not None:
            self.begin_time = m.get('BeginTime')

        if m.get('BillingInstanceId') is not None:
            self.billing_instance_id = m.get('BillingInstanceId')

        if m.get('CommodityCode') is not None:
            self.commodity_code = m.get('CommodityCode')

        if m.get('ComponentType') is not None:
            self.component_type = m.get('ComponentType')

        if m.get('Cu') is not None:
            self.cu = m.get('Cu')

        if m.get('DefaultGroup') is not None:
            self.default_group = m.get('DefaultGroup')

        if m.get('Description') is not None:
            self.description = m.get('Description')

        if m.get('DiskNumber') is not None:
            self.disk_number = m.get('DiskNumber')

        if m.get('ElasticNodeNumber') is not None:
            self.elastic_node_number = m.get('ElasticNodeNumber')

        if m.get('EnablePublicNetwork') is not None:
            self.enable_public_network = m.get('EnablePublicNetwork')

        if m.get('Endpoint') is not None:
            self.endpoint = m.get('Endpoint')

        if m.get('ExpireTime') is not None:
            self.expire_time = m.get('ExpireTime')

        if m.get('HttpPort') is not None:
            self.http_port = m.get('HttpPort')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('LocalStorageInstanceType') is not None:
            self.local_storage_instance_type = m.get('LocalStorageInstanceType')

        if m.get('MemoryCpuRatio') is not None:
            self.memory_cpu_ratio = m.get('MemoryCpuRatio')

        if m.get('NodeGroupId') is not None:
            self.node_group_id = m.get('NodeGroupId')

        if m.get('NodeGroupName') is not None:
            self.node_group_name = m.get('NodeGroupName')

        self.node_info = []
        if m.get('NodeInfo') is not None:
            for k1 in m.get('NodeInfo'):
                temp_model = main_models.DescribeNodeGroupsResponseBodyDataNodeInfo()
                self.node_info.append(temp_model.from_map(k1))

        if m.get('PayType') is not None:
            self.pay_type = m.get('PayType')

        if m.get('PublicAddress') is not None:
            self.public_address = m.get('PublicAddress')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('ResidentNodeNumber') is not None:
            self.resident_node_number = m.get('ResidentNodeNumber')

        if m.get('RunningTime') is not None:
            self.running_time = m.get('RunningTime')

        if m.get('SpecType') is not None:
            self.spec_type = m.get('SpecType')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('StoragePerformanceLevel') is not None:
            self.storage_performance_level = m.get('StoragePerformanceLevel')

        if m.get('StorageSize') is not None:
            self.storage_size = m.get('StorageSize')

        self.tags = []
        if m.get('Tags') is not None:
            for k1 in m.get('Tags'):
                temp_model = main_models.DescribeNodeGroupsResponseBodyDataTags()
                self.tags.append(temp_model.from_map(k1))

        if m.get('TargetElasticNodeNumber') is not None:
            self.target_elastic_node_number = m.get('TargetElasticNodeNumber')

        if m.get('ZoneId') is not None:
            self.zone_id = m.get('ZoneId')

        return self

class DescribeNodeGroupsResponseBodyDataTags(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        self.key = key
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self

class DescribeNodeGroupsResponseBodyDataNodeInfo(DaraModel):
    def __init__(
        self,
        node_id: str = None,
    ):
        self.node_id = node_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.node_id is not None:
            result['NodeId'] = self.node_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        return self

